@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Copyright (C) 2021-2024 Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) 2021-2025 Internet Systems Consortium, Inc. ("ISC")
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -18,9 +18,9 @@ prefix="/usr/pkg"
 # so that the unexpected situations with weird paths fall on the default
 # case of installed.
 script_path=$(cd "$(dirname "${0}")" && pwd)
-if test "${script_path}" = "/pbulk/work/net/kea/work/kea-2.6.3/src/share/database/scripts/pgsql"; then
+if test "${script_path}" = "XXX-tests-builddir-XXX/src/share/database/scripts/pgsql"; then
     # shellcheck source=./src/bin/admin/admin-utils.sh.in
-    . "/pbulk/work/net/kea/work/kea-2.6.3/src/bin/admin/admin-utils.sh"
+    . "XXX-tests-builddir-XXX/src/bin/admin/admin-utils.sh"
 else
     # shellcheck source=./src/bin/admin/admin-utils.sh.in
     . "${prefix}/share/kea/scripts/admin-utils.sh"
@@ -44,7 +44,7 @@ START TRANSACTION;
 
 -- -----------------------------------------------------------------------
 -- Extend the table holding DHCPv4 option definitions with a nullable
--- column matching option defintions with client classes.
+-- column matching option definitions with client classes.
 -- -----------------------------------------------------------------------
 ALTER TABLE dhcp4_option_def
     ADD COLUMN class_id BIGINT NULL DEFAULT NULL;
@@ -58,7 +58,7 @@ ALTER TABLE dhcp4_option_def
 
 -- -----------------------------------------------------------------------
 -- Extend the table holding DHCPv6 option definitions with a nullable
--- column matching option defintions with client classes.
+-- column matching option definitions with client classes.
 -- -----------------------------------------------------------------------
 ALTER TABLE dhcp6_option_def
     ADD COLUMN class_id BIGINT NULL DEFAULT NULL;
