@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Copyright (C) 2022-2024 Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) 2022-2025 Internet Systems Consortium, Inc. ("ISC")
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -18,9 +18,9 @@ prefix="/usr/pkg"
 # so that the unexpected situations with weird paths fall on the default
 # case of installed.
 script_path=$(cd "$(dirname "${0}")" && pwd)
-if test "${script_path}" = "/tmp/pkgbuild/net/kea/work/kea-2.6.3/src/share/database/scripts/pgsql"; then
+if test "${script_path}" = "XXX-tests-builddir-XXX/src/share/database/scripts/pgsql"; then
     # shellcheck source=./src/bin/admin/admin-utils.sh.in
-    . "/tmp/pkgbuild/net/kea/work/kea-2.6.3/src/bin/admin/admin-utils.sh"
+    . "XXX-tests-builddir-XXX/src/bin/admin/admin-utils.sh"
 else
     # shellcheck source=./src/bin/admin/admin-utils.sh.in
     . "${prefix}/share/kea/scripts/admin-utils.sh"
